DeferredExpression

Trait DeferredExpression 

pub trait DeferredExpression:
    Debug
    + Send
    + Sync {
    // Required methods
    fn finalize(&self) -> String;
    fn negate(&mut self);
    fn is_negated(&self) -> bool;
}
Trait for deferred query expressions that are finalized after main condition conversion.

In pySigma, deferred expressions postpone part of the query (e.g. Splunk | regex, | where) to the finish_query phase. Each backend can define custom deferred types.

Required Methods

fn finalize(&self) -> String

fn negate(&mut self)

fn is_negated(&self) -> bool

Implementors